 <?php
require_once(__DIR__ . '/inc/config.php');

$frags = '';
if(!empty($_SERVER['PATH_INFO'])) {
	$frags = $_SERVER['PATH_INFO'];
}
else {
	if(!empty($_SERVER['ORIG_PATH_INFO'])) {
		$frags = $_SERVER['ORIG_PATH_INFO'];
	}
}
$frags = explode("/", $frags);

// get city details
$is_empty_frags = false;
$suggest_cats_in_city = '';
if(!empty($frags[2])) {
	$stmt = $conn->prepare('SELECT * FROM cities WHERE city_id = :city_id');
	$stmt->bindValue(':city_id', $frags[2]);
	$stmt->execute();
	$row = $stmt->fetch(PDO::FETCH_ASSOC);
	$city_id    = $frags[2];
	$city_name  = $row['city_name'];
	$city_slug  = $row['slug'];
	$state_abbr = $row['state'];
	$state_id   = $row['state_id'];
	$lat        = $row['lat'];
	$lng        = $row['lng'];
}
else {
	$is_empty_frags = true;
	$city_id        = 0;
	$city_name      = '';
	$city_slug      = 'us';
	$state_abbr     = '';
	$state_id       = '';

	if(!empty($_COOKIE['city_id']) && !empty($_COOKIE['city_name']) && !empty($_COOKIE['city_slug'])) {
		$suggest_cats_in_city = $txt_suggest_city;
		$suggest_cats_in_city = str_replace('%city_name%' , $_COOKIE['city_name'] , $suggest_cats_in_city);
		$suggest_cats_in_city =
			'<a href="' . $baseurl . '/all-categories/' . $_COOKIE['city_slug'] . '/' . $_COOKIE['city_id'] . '">' . $suggest_cats_in_city . '</a>';
	}
}

if($city_id != 0) {
	$loc_slug = $city_slug;
	$loc_id = $city_id;
	$loc_type = 'c';
}
else {
	$loc_slug = $default_country_code;
	$loc_id = 0;
	$loc_type = 'n';
}

// count items in each cat
if($city_id != 0) {
	$query = "SELECT r.cat_id, COUNT(*) AS cat_count
			FROM rel_place_cat r
			INNER JOIN places p ON r.place_id = p.place_id
			WHERE r.city_id = :city_id AND p.status = 'approved'
			GROUP BY cat_id";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':city_id', $city_id);
	$stmt->execute();
}
else {
	$query = "SELECT r.cat_id, COUNT(*) AS cat_count
			FROM rel_place_cat r
			INNER JOIN places p ON r.place_id = p.place_id
			WHERE p.status = 'approved'
			GROUP BY cat_id";
	$stmt = $conn->prepare($query);
	$stmt->execute();
}

// init items count arr
$cat_items_count = array();

// build array with items count for each cat
while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	$cat_items_count[$row['cat_id']] = $row['cat_count'];
}

// select all cats information and put in an array
$cats_arr = array();
$query = "SELECT * FROM cats ORDER BY parent_id, cat_order";
$stmt = $conn->prepare($query);
$stmt->execute();
while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
	$cur_loop_arr = array(
		'cat_id'       => $row['id'],
		'plural_name'  => $row['plural_name'],
		'parent_id'    => $row['parent_id'],
		'iconfont_tag' => $row['iconfont_tag']
	);
	$cats_arr[] = $cur_loop_arr;
}

// return the indexes of $cats_arr where parent_id = 0
$parent_cats = array_keys(array_column($cats_arr, 'parent_id'), 0);

// initialize tree of category links
$tree = '';

foreach($parent_cats as $k => $v) {
	// parent cats
	$cat_id         = $cats_arr[$v]['cat_id'];
	$plural_name    = $cats_arr[$v]['plural_name'];
	$iconfont_tag   = $cats_arr[$v]['iconfont_tag'];
	$cat_slug       = to_slug($plural_name);
	$this_cat_count = (!empty($cat_items_count[$cat_id])) ? $cat_items_count[$cat_id] : 0;

	// sum items from all children and grandchildren
	$descendants = get_children_cats_ids($cat_id, $conn);

	$items_sum = $this_cat_count;
	foreach($descendants as $v) {
		$items_sum += (!empty($cat_items_count[$v])) ? $cat_items_count[$v] : 0;
	}

	// find children of each main parent cat
	$children = array_keys(array_column($cats_arr, 'parent_id'), $cat_id);

	// children count
	$total_children = count($children);

	// how many items in each col
	$each_col = ceil($total_children / 4);
	$col_count = 1;
	$each_main_cat_total_count = 0;

	// show parent cat link
	// $tree .= '<div class="cat-group">';
	$tree .= '	<div class="top-level-cat">';
	$tree .= '		<a href="' . "$baseurl/$loc_slug/list/$cat_slug/$loc_type-$loc_id-$cat_id-1" . '">';
	$tree .= 			"$iconfont_tag <span class=\"cat-text\">$plural_name ($items_sum)</span>";
	$tree .= '		</a>';
	$tree .= '	</div><!-- end .top-level-cat -->';

	// children cats
	if($total_children > 0 ) {
		$tree .= '<div class="clear"></div>';
		$tree .= '<div class="cat-col">';
		$tree .= '	<ul class="children-cat">';

		foreach($children as $k2 => $v2) {
			// details of each child cat
			$cat_id2         = $cats_arr[$v2]['cat_id'];
			$plural_name2    = $cats_arr[$v2]['plural_name'];
			$cat_slug2       = to_slug($plural_name2);
			$this_cat_count2 = (!empty($cat_items_count[$cat_id2])) ? $cat_items_count[$cat_id2] : 0;

			// sum
			$items_sum = $this_cat_count2;

			// find children of each child
			$grandchildren = array_keys(array_column($cats_arr, 'parent_id'), $cat_id2);

			foreach($grandchildren as $v) {
				$items_sum += (!empty($cat_items_count[$cats_arr[$v]['cat_id']])) ? $cat_items_count[$cats_arr[$v]['cat_id']] : 0;
			}

			// tree html code
			if($col_count > $each_col) {
				// reset col counter
				$col_count = 1;

				// close col tags and start new one
				$tree .= '	</ul>';
				$tree .= '</div><!-- .cat-col -->';
				$tree .= '<div class="cat-col">';
				$tree .= '	<ul class="children-cat">';
			}

			$tree .= '<li>';
			$tree .= '	<a href="' . "$baseurl/$loc_slug/list/$cat_slug2/$loc_type-$loc_id-$cat_id2-1" . '">';
			$tree .= 		$plural_name2 . "($items_sum)";
			$tree .= '	</a>';

			if(!empty($grandchildren)) {
				$tree .= ' <div class="btn-group">';
					$tree .= '<a href="#" class="dropdown-toggle" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">';
					$tree .= '<i class="fa fa-plus-circle"></i></a>';

					$tree .= '<ul class="dropdown-menu">';
					foreach($grandchildren as $k2 => $v2) {
						// details of each grandchild cat
						$cat_id3     = $cats_arr[$v2]['cat_id'];
						$plural_name3 = $cats_arr[$v2]['plural_name'];
						$cat_slug3   = to_slug($plural_name3);
						$this_cat_count3 = (!empty($cat_items_count[$cat_id3])) ? $cat_items_count[$cat_id3] : 0;

						$tree .= '<li>';
							$tree .= '<a href="' . $baseurl . '/' . $loc_slug . '/list/' . $cat_slug3 . '/' . $loc_type . '-' . $loc_id . '-' . $cat_id3 . '-1">' . $plural_name3 . "($this_cat_count3)" . '</a>';
						$tree .= '</li>';
					}
					$tree .= '</ul>';
				$tree .= '</div><!-- .btn-group -->';
			}

			$tree .= '</li>';

			// increment col count
			$col_count++;
			$each_main_cat_total_count++;
			if($each_main_cat_total_count == $total_children) {
				$tree .= '</ul>';
				$tree .= '</div><!-- .cat-col -->';
				$tree .= '<div class="clearfix"></div>';
			}
		}
	}
	// $tree .= '</div><!-- .cat-group -->';
}

// translation replacements
if(!empty($city_id)) {
	// case: city defined
	$txt_html_title_1 = str_replace('%city_name%' , $city_name , $txt_html_title_1);
	$txt_html_title_1 = str_replace('%state_abbr%', $state_abbr, $txt_html_title_1);
	$txt_meta_desc_1  = str_replace('%city_name%' , $city_name , $txt_meta_desc_1);
	$txt_meta_desc_1  = str_replace('%state_abbr%', $state_abbr, $txt_meta_desc_1);
	$txt_main_title_1 = str_replace('%city_name%' , $city_name , $txt_main_title_1);
	$txt_main_title_1 = str_replace('%state_abbr%', $state_abbr, $txt_main_title_1);

	$txt_html_title = $txt_html_title_1;
	$txt_meta_desc  = $txt_meta_desc_1;
	$txt_main_title = $txt_main_title_1;
}
else {
	$txt_html_title = $txt_html_title_2;
	$txt_meta_desc  = $txt_meta_desc_2;
	$txt_main_title = $txt_main_title_2;
}

// template file
require_once(__DIR__ . '/templates/tpl_all-categories.php');